#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 paramtree
version:              0.1.2
visibility:           public
id:                   paramtree-0.1.2-KkVuvQsKnxHBRtYAJs3cLZ
key:                  paramtree-0.1.2-KkVuvQsKnxHBRtYAJs3cLZ
license:              BSD-3-Clause
copyright:            Copyright © 2017-2023 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/paramtree
synopsis:
    Generate labelled test/benchmark trees from sets of parameters

description:
    Easily generate a labelled tree of tests/benchmarks from a generation
    function and sets of parameters to use for each of that functions
    arguments. Example usecases include criterion benchmark trees or tasty test
    trees.

category:             Development, Benchmarking, Testing
abi:                  52350f5755d687b9f0d842e7db8bb800
exposed:              True
exposed-modules:      ParamTree
import-dirs:          /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/paramtree-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-paramtree
hs-libraries:         HSparamtree-0.1.2-KkVuvQsKnxHBRtYAJs3cLZ
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-paramtree/html/paramtree.haddock
haddock-html:         /usr/share/doc/haskell-paramtree/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

